@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 use std::fmt;
 
 use crate::fs::feature::xattr;
@@ -19,13 +25,14 @@ DISPLAY OPTIONS
   -R, --recurse              recurse into directories
   -T, --tree                 recurse into directories as a tree
   -X, --dereference          dereference symbolic links when displaying information
-  -F, --classify             display type indicator by file names
+  -F, --classify=WHEN        display type indicator by file names (always, auto, never)
   --colo[u]r=WHEN            when to use terminal colours (always, auto, never)
   --colo[u]r-scale           highlight levels of 'field' distinctly(all, age, size)
   --colo[u]r-scale-mode      use gradient or fixed colors in --color-scale (fixed, gradient)
   --icons=WHEN               when to display icons (always, auto, never)
   --no-quotes                don't quote file names with spaces
   --hyperlink                display entries as hyperlinks
+  --absolute                 display entries with their absolute path (on, follow, off)
   -w, --width COLS           set screen width in columns
 
 
