@@ -1,3 +1,9 @@
+// SPDX-FileCopyrightText: 2024 Christina Sørensen
+// SPDX-License-Identifier: EUPL-1.2
+//
+// SPDX-FileCopyrightText: 2023-2024 Christina Sørensen, eza contributors
+// SPDX-FileCopyrightText: 2014 Benjamin Sago
+// SPDX-License-Identifier: MIT
 use nu_ansi_term::Style;
 use phf::{phf_map, Map};
 
@@ -615,6 +621,7 @@ const EXTENSION_ICONS: Map<&'static str, char> = phf_map! {
     "ogg"            => Icons::AUDIO,            // 
     "ogm"            => Icons::VIDEO,            // 
     "ogv"            => Icons::VIDEO,            // 
+    "opml"           => Icons::XML,              // 󰗀
     "opus"           => Icons::AUDIO,            // 
     "orf"            => Icons::IMAGE,            // 
     "org"            => '\u{e633}',              // 
